Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Files ¶
Files searches for files matching the path patterns, where '**' is any number of folders and '*' is any substring. A file only has to match one of the patterns. If no patterns are given then all files under the current folder that contain the filter substring are taken.
Note: filter matching uses 'git grep' so only files that are added to git can be found by that method.
func LongestFixedPart ¶
LongestFixedPart gives the longest substring not containing any wildcards.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.